@@ -1,7 +1,7 @@
 package App::DuckPAN;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: The DuckDuckGo DuckPAN client
-$App::DuckPAN::VERSION = '0.196';
+$App::DuckPAN::VERSION = '0.198';
 use feature 'state';
 
 use Moo;
@@ -208,6 +208,12 @@ sub get_reply {
 	return $return;
 }
 
+sub ask_yn {
+	my ( $self, $prompt, %params ) = @_;
+
+	return $self->term->ask_yn( prompt => $prompt, %params );
+}
+
 has http => (
 	is => 'ro',
 	builder => '_build_http',
@@ -626,7 +632,7 @@ App::DuckPAN - The DuckDuckGo DuckPAN client
 
 =head1 VERSION
 
-version 0.196
+version 0.198
 
 =head1 DuckPAN
 
