@@ -1,7 +1,7 @@
 package App::DuckPAN::Web;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.196';
+$App::DuckPAN::Web::VERSION = '0.198';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -46,12 +46,6 @@ has ua => (
 	},
 );
 
-# ddhX servers to use for API calls.
-has ddh_servers => (
-	is => 'ro',
-	default => sub { [reverse 1..10] }
-);
-
 sub BUILD {
 	my ( $self ) = @_;
 	my %share_dir_hash;
@@ -103,16 +97,20 @@ sub request {
 		for (keys %{$self->_share_dir_hash}) {
 			if ($request->path =~ m|^/$_/|g) {
 
-				$share_dir = $_;
-				my $filename = pop @path_parts;
-				my $remainder = $request->path;
-				$remainder =~ s|$share_dir||;
-				$remainder =~ s|$filename||;
-				$remainder =~ s|//|/|;
-				$remainder =~ s|^/\d{3,4}||;
-
-				$filename = $remainder . $filename if $remainder;
+                               $share_dir = $_;
+                               # Get filename from path and url unescape
+                               my $filename = uri_unescape( pop @path_parts );
+                               # Trim path from left to right to find parent dir of filename
+                               # e.g /share/goodie/foo/foo_imgs/image.png -> "foo_imgs"
+                               my $remainder = $request->path_info;
+                               $remainder =~ s|$share_dir||;
+                               $remainder =~ s|$filename||;
+                               $remainder =~ s|//|/|;
+                               $remainder =~ s|^/\d{3,4}||;
 
+                               # if valid remainder exists, prepend to filename
+                               $filename = "$remainder$filename" if $remainder ne $filename;
+                
 				if (my $filename_path = $self->_share_dir_hash->{$share_dir}->can('share')->($filename)) {
 
 					my $content_type = Plack::MIME->mime_type($filename);
@@ -171,52 +169,47 @@ sub request {
 					$to =~ s/\$\{dollar\}/\$/g;
 
 					my ($wrap_jsonp_callback, $callback, $wrap_string_callback, $missing_envs, $accept_header) =
-						($rewrite->wrap_jsonp_callback, $rewrite->callback, $rewrite->wrap_string_callback, $rewrite->missing_envs, $rewrite->accept_header);
+						($rewrite->wrap_jsonp_callback, $rewrite->callback, $rewrite->wrap_string_callback, defined($rewrite->missing_envs), $rewrite->accept_header);
 
 					# Check if environment variables (most likely the API key) is missing.
 					# If it is missing, switch to the DDG endpoint.
 					my ($use_ddh, $request_uri);
-					if(defined $missing_envs) {
+					if($missing_envs) {
 						++$use_ddh;
 						$request_uri = $request->request_uri;
 						 # Display the URL that we used.
 						 print "\nAPI key not found. Using DuckDuckGo's endpoint:\n";
 					}
 
-					my @ddh = @{$self->ddh_servers};
-					for my $ddh (@ddh){
-						$to = "https://ddh$ddh.duckduckgo.com$request_uri" if $use_ddh;
-						p($to);
+					$to = "https://beta.duckduckgo.com$request_uri" if $use_ddh;
+					p($to);
 
-						my $res = $self->ua->request(HTTP::Request->new(
-							GET => $to,
-							[ $accept_header ? (Accept => $accept_header) : () ]
-						));
+					my $res = $self->ua->request(HTTP::Request->new(
+						GET => $to,
+						[ $accept_header ? (Accept => $accept_header) : () ]
+					));
 
-						if ($res->is_success) {
-							$body = $res->decoded_content;
-							# Encode utf8 api_responses to bytestream for Plack.
-							utf8::encode $body if utf8::is_utf8 $body;
-							warn "Cannot use wrap_jsonp_callback and wrap_string callback at the same time!" if $wrap_jsonp_callback && $wrap_string_callback;
-							if ($wrap_jsonp_callback && $callback) {
-								$body = $callback.'('.$body.');' unless defined $missing_envs;
-							}
-							elsif ($wrap_string_callback && $callback) {
-								$body =~ s/"/\\"/g;
-								$body =~ s/\n/\\n/g;
-								$body =~ s/\R//g;
-								$body = qq{$callback("'.$body.'");} unless defined $missing_envs;
-							}
-							$response->code($res->code);
-							$response->content_type($res->content_type);
+					if ($res->is_success) {
+						$body = $res->decoded_content;
+						# Encode utf8 api_responses to bytestream for Plack.
+						utf8::encode $body if utf8::is_utf8 $body;
+						warn "Cannot use wrap_jsonp_callback and wrap_string callback at the same time!" if $wrap_jsonp_callback && $wrap_string_callback;
+						if ($wrap_jsonp_callback && $callback) {
+							$body = $callback.'('.$body.');' unless $missing_envs;
 						}
-						else {
-							next if $use_ddh && ($ddh != $ddh[-1]);
-							p($res->status_line, color => { string => 'red' });
-							my $errormsg = (pop @{[split'::', $spice_class]}). ": ".$res->status_line;
-							$body = '$("#message").removeClass("is-hidden").append("<div class=\"msg msg--warning\">'. $errormsg .'</div>");';
+						elsif ($wrap_string_callback && $callback) {
+							$body =~ s/"/\\"/g;
+							$body =~ s/\n/\\n/g;
+							$body =~ s/\R//g;
+							$body = qq{$callback("'.$body.'");} unless $missing_envs;
 						}
-						last;
+						$response->code($res->code);
+						$response->content_type($res->content_type);
+					}
+					else {
+						p($res->status_line, color => { string => 'red' });
+						my $errormsg = (pop @{[split'::', $spice_class]}). ": ".$res->status_line;
+						$body = '$("#message").removeClass("is-hidden").append("<div class=\"msg msg--warning\">'. $errormsg .'</div>");';
 					}
 				}
 			}
@@ -571,7 +564,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.196
+version 0.198
 
 =head1 AUTHOR
 
